@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-def connect(p_str):
+def connect(p_connecturl):
+    if p_connecturl:
+        pass
     raise SQLCliODBCException("SQLCLI-0000: Unable to find the local dynamic library. \n"
                               "You may need to reinstall or use 'Python setup.py build_ext' to generate it.")
 
